package com.hfkj.openapi.v1.model.request;

import lombok.Data;
import org.hibernate.validator.constraints.Length;
import javax.validation.constraints.DecimalMax;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotBlank;
import java.math.BigDecimal;

/**
 * 请求转账模型
 * @className: RequestTransferAccountsModel
 * @author: HuRui
 * @date: 2023/10/23
 **/
@Data
public class RequestTransferAccountsModel {

    /**
     * 商户号
     */
    @NotBlank(message = "商户号必填项")
    private String merchantNo;

    /**
     * 订单号
     */
    @NotBlank(message = "订单号必填项")
    private String orderNo;

    /**
     * 转账金额
     */
    @DecimalMax(value = "99999999", message = "转账最大金额99999999元")
    @DecimalMin(value = "0.01", message = "转账最小金额0.01元")
    @NotBlank(message = "转账金额必填项")
    private String amount;

    /**
     * 转账金额
     */
    @Length(max = 300, message = "订单标题长度限制在300字符以内")
    private String content;

    /**
     * 签名参数
     */
    @NotBlank(message = "签名必填项")
    private String sign;

}
